@@ -17,16 +17,18 @@ __revision__ = ""
 
 import networkx as NX
 from networkx.generators.atlas import *
+from pygraphviz import *
 
 atlas=graph_atlas_g()[0:20]
 
+
 for G in atlas:
     print "graph %s has %d nodes with %d edges"\
           %(G.name,NX.number_of_nodes(G),NX.number_of_edges(G))
-    A=NX.pygraphviz_from_networkx(G)
-    A.set_attr(label=G.name) # set label to graph n ame
+    A=NX.to_agraph(G)
+    A.graph_attr['label']=G.name 
     # set default node attributes
-    A.set_node_attr(color='red',style='filled',shape='circle') 
-    
-    fh=open(G.name+'.dot','w')
-    A.write(fh)
+    A.node_attr['color']='red'
+    A.node_attr['style']='filled'
+    A.node_attr['shape']='circle'
+    A.write(G.name+'.dot')
