@@ -66,23 +66,33 @@ from path import  \
      dijkstra_path, dijkstra_path_length, bidirectional_dijkstra,\
      single_source_dijkstra_path, single_source_dijkstra_path_length,\
      single_source_dijkstra,\
-     dijkstra_predecessor_and_distance, predecessor, floyd_warshall,\
-     bfs, dfs
+     dijkstra_predecessor_and_distance, predecessor, floyd_warshall
 from dag import \
      topological_sort, topological_sort_recursive,\
      is_directed_acyclic_graph
 from component import \
      number_connected_components, connected_components,\
      is_connected, connected_component_subgraphs,\
-     node_connected_component
+     node_connected_component,\
+     number_strongly_connected_components, strongly_connected_components,\
+     is_strongly_connected, strongly_connected_component_subgraphs,\
+     strongly_connected_components_recursive,\
+     kosaraju_strongly_connected_components
+
 from search import dfs_preorder, dfs_postorder, dfs_predecessor,\
-            dfs_successor, bfs_length, bfs_path, dfs_forest
+            dfs_successor, dfs_tree
 from cluster import triangles, average_clustering, clustering, transitivity
 from operators import union, cartesian_product, compose, complement,\
                       disjoint_union, create_empty_copy,\
                       subgraph, convert_to_undirected, convert_to_directed,\
                       convert_node_labels_to_integers, relabel_nodes
 from centrality import betweenness_centrality, \
+                       betweenness_centrality_source, \
+                       load_centrality,\
+                       newman_betweenness_centrality,\
+                       brandes_betweenness_centrality,\
+                       edge_betweenness,\
+                       edge_load,\
                        degree_centrality, \
                        closeness_centrality
 from hybrid import kl_connected_subgraph, is_kl_connected
@@ -102,12 +112,8 @@ except ImportError:
 
 from utils import is_string_like, iterable,\
                   pareto_sequence, powerlaw_sequence, uniform_sequence,\
-                  cumulative_distribution, discrete_sequence
-from io import write_gpickle, read_gpickle, \
-   read_edgelist, write_edgelist, \
-   read_multiline_adjlist, write_multiline_adjlist, \
-   read_adjlist, write_adjlist,\
-   read_yaml, write_yaml
+                  cumulative_distribution, discrete_sequence,_get_fh
+
 
 from convert import from_whatever,\
      from_dict_of_dicts, to_dict_of_dicts,\
@@ -121,6 +127,9 @@ from generators.small import *
 from generators.random_graphs import *
 from generators.degree_seq import *
 from generators.directed import *
+# drawing
 from drawing import *
+# read/write graphs in various formats
+from readwrite import *
 
 from tests import run as test
