@@ -7,15 +7,6 @@ try:
 except ImportError:
     pass
 
-try:
-    # needs pygraphviz, graphviz
-    # if successful,
-    # write_dot, read_dot, graphviz_layout will come from pygraphviz Agraph
-    # version 0.21 or earlier
-    from nx_pygraphviz import *
-except ImportError:
-    pass
-
 try:
     # needs pygraphviz, graphviz
     # if successful,
@@ -26,13 +17,13 @@ except ImportError:
     pass
 
 try:
-    # needs matplotlib (including either numpy, Numeric, or numarray)
+    # needs matplotlib 
     from nx_pylab import *
 except ImportError:
     pass
 
 try:
-    # needs numpy or Numeric
+    # needs numpy 
     from layout import *
 except ImportError:
     pass
