@@ -68,7 +68,7 @@ def configuration_model(deg_sequence,seed=None):
     of complex networks", SIAM REVIEW 45-2, pp 167-256, 2003.
         
     """
-    if not is_valid_degree_sequence(deg_sequence):
+    if not sum(deg_sequence)%2 ==0:
         raise networkx.NetworkXError, 'Invalid degree sequence'
 
     if not seed is None:
@@ -94,14 +94,12 @@ def configuration_model(deg_sequence,seed=None):
         for i in range(deg_sequence[n-1]):
             stublist.append(n)
 
-    # while there are stubs in the sublist, randomly select two stubs,
-    # connect them to make an edge, then pop them from the stublist    
+    # shuffle stublist and assign pairs by removing 2 elements at a time      
+    random.shuffle(stublist)
     while stublist:
-        source=random.choice(stublist)
-        stublist.remove(source)
-        target=random.choice(stublist)
-        stublist.remove(target)
-        G.add_edge(source,target)
+        n1 = stublist.pop()
+        n2 = stublist.pop()
+        G.add_edge(n1,n2)
 
     G.name="configuration_model %d nodes %d edges"%(G.order(),G.size())
     return G
@@ -313,15 +311,15 @@ def is_valid_degree_sequence(deg_sequence):
 
 def create_degree_sequence(n, sfunction=None, max_tries=50, **kwds):
     """ Attempt to create a valid degree sequence of length n using
-    specified function sfunction(n,kwds).
+    specified function sfunction(n,**kwds).
 
       - `n`: length of degree sequence = number of nodes
-      - `sfunction`: a function, called as "sfunction(n,kwds)",
+      - `sfunction`: a function, called as "sfunction(n,**kwds)",
          that returns a list of n real or integer values.
       - `max_tries`: max number of attempts at creating valid degree
          sequence.
 
-    Repeatedly create a degree sequence by calling sfunction(n,kwds)
+    Repeatedly create a degree sequence by calling sfunction(n,**kwds)
     until achieving a valid degree sequence. If unsuccessful after
     max_tries attempts, raise an exception.
     
@@ -351,11 +349,12 @@ def double_edge_swap(G, nswap=1):
     Return count of successful swaps.
     The graph G is modified in place.
     A double-edge swap removes two randomly choseen edges u-v and x-y
-    and creates the new edges u-x and v-y:
+    and creates the new edges u-x and v-y::
+
+     u--v            u  v
+            becomes  |  |
+     x--y            x  y
 
-    u--v            u  v
-           becomes  |  |
-    x--y            x  y
 
     If either the edge u-x or v-y already exist no swap is performed so
     the actual count of swapped edges is always <= nswap
@@ -400,18 +399,19 @@ def connected_double_edge_swap(G, nswap=1):
     The graph G is modified in place.
 
     A double-edge swap removes two randomly choseen edges u-v and x-y
-    and creates the new edges u-x and v-y:
+    and creates the new edges u-x and v-y::
+
+     u--v            u  v
+            becomes  |  |
+     x--y            x  y
 
-    u--v            u  v
-           becomes  |  |
-    x--y            x  y
 
     If either the edge u-x or v-y already exist no swap is performed so
     the actual count of swapped edges is always <= nswap
 
     The initial graph G must be connected and the resulting graph is connected.
 
-    Reference:
+    Reference::
 
      @misc{gkantsidis-03-markov,
       author = "C. Gkantsidis and M. Mihail and E. Zegura",
@@ -419,7 +419,8 @@ def connected_double_edge_swap(G, nswap=1):
                power law random graphs",
       year = "2003",
       url = "http://citeseer.ist.psu.edu/gkantsidis03markov.html"
-      }
+     }
+
 
     """
     import math
@@ -481,9 +482,9 @@ def li_smax_graph(degree_seq):
     Maximum s-metrix  means that high degree nodes are connected to high
     degree nodes. 
         
-    - `deg_sequence`: degree sequence, a list of integers with each entry
-      corresponding to the degree of a node.
-      A non-graphical degree sequence raises an Exception.    
+    - `degree_seq`: degree sequence, a list of integers with each entry
+       corresponding to the degree of a node.
+       A non-graphical degree sequence raises an Exception.    
 
     Reference::      
     
@@ -496,39 +497,40 @@ def li_smax_graph(degree_seq):
        year = {2005}
       }
 
-    The algorithm
+    The algorithm::
 
-    STEP 0 - Initialization
-    A = {0}
-    B = {1, 2, 3, ..., n}
-    O = {(i; j), ..., (k, l),...} where i < j, i <= k < l and 
-            d_i * d_j >= d_k *d_l 
-    wA = d_1
-    dB = sum(degrees)
+     STEP 0 - Initialization
+     A = {0}
+     B = {1, 2, 3, ..., n}
+     O = {(i; j), ..., (k, l),...} where i < j, i <= k < l and 
+             d_i * d_j >= d_k *d_l 
+     wA = d_1
+     dB = sum(degrees)
 
-    STEP 1 - Link selection
-    (a) If |O| = 0 TERMINATE. Return graph A.
-    (b) Select element(s) (i, j) in O having the largest d_i * d_j , if for 
-            any i or j either w_i = 0 or w_j = 0 delete (i, j) from O
-    (c) If there are no elements selected go to (a).
-    (d) Select the link (i, j) having the largest value w_i (where for each 
-            (i, j) w_i is the smaller of w_i and w_j ), and proceed to STEP 2.
+     STEP 1 - Link selection
+     (a) If |O| = 0 TERMINATE. Return graph A.
+     (b) Select element(s) (i, j) in O having the largest d_i * d_j , if for 
+             any i or j either w_i = 0 or w_j = 0 delete (i, j) from O
+     (c) If there are no elements selected go to (a).
+     (d) Select the link (i, j) having the largest value w_i (where for each 
+             (i, j) w_i is the smaller of w_i and w_j ), and proceed to STEP 2.
+
+     STEP 2 - Link addition
+     Type 1: i in A and j in B. 
+             Add j to the graph A and remove it from the set B add a link 
+             (i, j) to the graph A. Update variables:
+             wA = wA + d_j -2 and dB = dB - d_j
+             Decrement w_i and w_j with one. Delete (i, j) from O
+     Type 2: i and j in A.
+         Check Tree Condition: If dB = 2 * |B| - wA. 
+             Delete (i, j) from O, continue to STEP 3
+         Check Disconnected Cluster Condition: If wA = 2. 
+             Delete (i, j) from O, continue to STEP 3
+         Add the link (i, j) to the graph A 
+         Decrement w_i and w_j with one, and wA = wA -2
+     STEP 3
+         Go to STEP 1
 
-    STEP 2 - Link addition
-    Type 1: i in A and j in B. 
-            Add j to the graph A and remove it from the set B add a link 
-            (i, j) to the graph A. Update variables:
-            wA = wA + d_j -2 and dB = dB - d_j
-            Decrement w_i and w_j with one. Delete (i, j) from O
-    Type 2: i and j in A.
-        Check Tree Condition: If dB = 2 * |B| - wA. 
-            Delete (i, j) from O, continue to STEP 3
-        Check Disconnected Cluster Condition: If wA = 2. 
-            Delete (i, j) from O, continue to STEP 3
-        Add the link (i, j) to the graph A 
-        Decrement w_i and w_j with one, and wA = wA -2
-    STEP 3
-        Go to STEP 1
 
     The article states that the algorithm will result in a maximal s-metric. 
     This implementation can not guarantee such maximality. I may have 
@@ -672,14 +674,15 @@ def s_metric(G):
     
     Reference::
 
-    @unpublished{li-2005,
-     author = {Lun Li and David Alderson and
+     @unpublished{li-2005,
+      author = {Lun Li and David Alderson and
                John C. Doyle and Walter Willinger},
-     title = {Towards a Theory of Scale-Free Graphs:
-              Definition, Properties, and  Implications (Extended Version)},
-     url = {http://arxiv.org/abs/cond-mat/0501169},
-     year = {2005}
-     }
+      title = {Towards a Theory of Scale-Free Graphs:
+               Definition, Properties, and  Implications (Extended Version)},
+      url = {http://arxiv.org/abs/cond-mat/0501169},
+      year = {2005}
+      }
+
     """
     # this function doesn't belong in this module
     return sum([G.degree(u)*G.degree(v) for (u,v) in G.edges_iter()])
