@@ -261,7 +261,7 @@ class XDiGraph(DiGraph):
                 self.pred[n1].has_key(n2))    
     
 
-    def get_edge_iter(self, u, v):
+    def get_edge_iter(self, u, v=None):
         """Return an iterator over the objects associated with each edge
         from node u to node v.
 
@@ -269,16 +269,16 @@ class XDiGraph(DiGraph):
         if v is None:
             (u,v)=u
         try:
-            result = self.adj[u][v]    # raises KeyError if edge not found
-            if self.multiedges:
-                for data in result:
-                    yield data
-            else:
-                yield result
+            data = self.adj[u][v]    # raises KeyError if edge not found
         except KeyError:
-            pass
+            raise NetworkXError, "Edge (%s,%s) requested via get_edge_iter does not exist."%(u,v)
+        if self.multiedges:
+            for d in data:
+                yield d
+        else:
+            yield data
 
-    def get_edge(self, u, v):
+    def get_edge(self, u, v=None):
         """Return the objects associated with each edge from node u to node v.
 
         If multiedges=False, a single object is returned.
@@ -286,11 +286,15 @@ class XDiGraph(DiGraph):
         If no edge exists, None is returned.
 
         """
-        edge_data=list(self.get_edge_iter(u,v))
+        if v is None:
+            (u,v)=u
+        try:
+            data=self.adj[u][v]
+        except KeyError:
+            raise NetworkXError, "Edge (%s,%s) requested via get_edge does not exist."%(u,v)
         if self.multiedges:
-            return edge_data
-        else:
-            return edge_data[0]
+            return data[:]  # copy of the list
+        return data
 
     def delete_multiedge(self, n1, n2):
         """ Delete all edges between nodes n1 and n2.
@@ -442,14 +446,30 @@ class XDiGraph(DiGraph):
         Returns the same data as in_edges(n) but in a different format.
 
         """
-        if n not in self:
+        try:
+            if self.multiedges:
+                for nbr,elist in self.pred[n].iteritems():
+                    for data in elist:
+                        yield nbr
+            else:
+                for nbr in self.pred[n].iterkeys():
+                    yield nbr
+        except KeyError:
             raise NetworkXError, "node %s not in graph"%(n,)
-        for (u,v,d) in self.in_edges_iter(n):
-            yield u
 
     edges_iter=out_edges_iter
     neighbors_iter=successors_iter
 
+    def predecessors(self, n):
+        """Return predecessor nodes of n."""
+        return list(self.predecessors_iter(n))
+
+    def successors(self, n):
+        """Return sucessor nodes of n."""
+        return list(self.successors_iter(n))
+
+    neighbors=successors
+
     def in_degree_iter(self, nbunch=None, with_labels=False):
         """Return iterator for in_degree(n) or (n,in_degree(n))
         for all n in nbunch.
